@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 # version
-$OOB::VERSION = '1.00';
+$OOB::VERSION = '1.01';
 
 # modules that we need
 use Scalar::Util qw( blessed refaddr reftype );
@@ -432,7 +432,7 @@ OOB - out of band data for any data structure in Perl
 
 =head1 VERSION
 
-This documentation describes version 1.00.
+This documentation describes version 1.01.
 
 =head1 SYNOPSIS
 
@@ -613,9 +613,9 @@ of that).
 
 Elizabeth Mattijsen, <liz@dijkmat.nl>.
 
-maintained by LNATION, <thisusedtobeanemail@gmail.com>
+maintained by LNATION, <email@lnation.org>.
 
-Please report bugs to <perlbugs@dijkmat.nl>.
+Please report bugs to <email@lnation.org>.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -631,8 +631,8 @@ the C<OOB> module.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Elizabeth Mattijsen <liz@dijkmat.nl>. All rights
-reserved.  This program is free software; you can redistribute it and/or
+Copyright (c) 2008 Elizabeth Mattijsen <liz@dijkmat.nl>. 2019-2025 LNATION <email@lnation.org>
+All rights reserved.  This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =cut
